<?php
require './CV-JS_foldertree_settings.php';


class fs
{
	protected $base = null;

	protected function real($path) {
		$temp = realpath($path);
		if(!$temp) { throw new Exception('Path does not exist: ' . $path); }
		if($this->base && strlen($this->base)) {
			if(strpos($temp, $this->base) !== 0) { throw new Exception('Path is not inside base ('.$this->base.'): ' . $temp); }
		}
		return $temp;
	}
	protected function path($id) {
		$id = str_replace('/', DIRECTORY_SEPARATOR, $id);
		$id = trim($id, DIRECTORY_SEPARATOR);
		$id = $this->real($this->base . DIRECTORY_SEPARATOR . $id);
		return $id;
	}
	protected function id($path) {
		$path = $this->real($path);
		$path = substr($path, strlen($this->base));
		$path = str_replace(DIRECTORY_SEPARATOR, '/', $path);
		$path = trim($path, '/');
		return strlen($path) ? $path : '/';
	}

	public function __construct($base) {
		$this->base = $this->real($base);
		if(!$this->base) { throw new Exception('Base directory does not exist'); }
	}
	public function lst($id, $with_root = false) {
		$dir = $this->path($id);
		$lst = @scandir($dir);
		if(!$lst) { throw new Exception('Could not list path: ' . $dir); }
		$res = array();
		foreach($lst as $item) {
			if($item == '.' || $item == '..' || $item === null) { continue; }
//2018_06_21			$tmp = preg_match('([^ a-z?-?-_0-9.]+)ui', $item);
//			if($tmp === false || $tmp === 1) { continue; }
			if(is_dir($dir . DIRECTORY_SEPARATOR . $item)) {
				$res[] = array('text' => $item, 'children' => true,  'id' => $this->id($dir . DIRECTORY_SEPARATOR . $item), 'icon' => 'folder');
			}
			else {
				$res[] = array('text' => $item, 'children' => false, 'id' => $this->id($dir . DIRECTORY_SEPARATOR . $item), 'type' => 'file', 'icon' => 'file file-'.substr($item, strrpos($item,'.') + 1));
			}
		}
		if($with_root && $this->id($dir) === '/') {
			$res = array(array('text' => basename($this->base), 'children' => $res, 'id' => '/', 'icon'=>'folder', 'state' => array('opened' => true, 'disabled' => true)));
		}
		return $res;
	}
	public function data($id) {
		if(strpos($id, ":")) {
			$id = array_map(array($this, 'id'), explode(':', $id));
			return array('type'=>'multiple', 'content'=> 'Multiple selected: ' . implode(' ', $id));
		}
		$dir = $this->path($id);
		if(is_dir($dir)) {
			return array('type'=>'folder', 'content'=> $id);
		}
		if(is_file($dir)) {
			$ext = strpos($dir, '.') !== FALSE ? substr($dir, strrpos($dir, '.') + 1) : '';
			$dat = array('type' => $ext, 'content' => '');
			switch($ext) {
				case 'bmp':
				case 'txt':
				case 'text':
				case 'md':
				case 'js':
				case 'json':
				case 'css':
				case 'html':
				case 'htm':
				case 'xml':
				case 'c':
				case 'cpp':
				case 'h':
				case 'sql':
				case 'log':
				case 'py':
				case 'rb':
				case 'htaccess':
				case 'php':
					$dat['content'] = file_get_contents($dir);
					break;
				case 'JPG':
				case 'JPEG':
				case 'GIF':
				case 'PNG':
				case 'PDF':
				case 'SVG':
				case 'jpg':
				case 'jpeg':
				case 'gif':
				case 'png': $dat['content'] = $this->id($dir); break;
				case 'svg': $dat['content'] = $this->id($dir); break;
				case 'PDF':
				case 'DGN':
				case 'PCF':
				case 'DXF':
				case 'DWG':
				case 'DWF':
				case 'pdf':
				case 'dgn':
				case 'pcf':
				case 'dxf':
				case 'dwg':
				case 'dwf': $dat['content'] = $this->id($dir); break;
				default:
					$dat['content'] = 'File not recognized: '.$this->id($dir);
					break;
			}
			return $dat;
		}
		throw new Exception('Not a valid selection: ' . $dir);
	}
	public function create($id, $name, $mkdir = false) {
		$dir = $this->path($id);		
//		if(preg_match('([^ a-z?-?-_0-9.]+)ui', $name) || !strlen($name)) {
//			throw new Exception('Invalid name: ' . $name);
//		}
		if($mkdir) {
			mkdir($dir . DIRECTORY_SEPARATOR . $name);
		}
		else {
			file_put_contents($dir . DIRECTORY_SEPARATOR . $name, '');
		}
		return array('id' => $this->id($dir . DIRECTORY_SEPARATOR . $name));
	}
	public function rename($id, $name) {
		$dir = $this->path($id);
		if($dir === $this->base) {
			throw new Exception('Cannot rename root');
		}
//		if(preg_match('([^ a-z?-?-_0-9.]+)ui', $name) || !strlen($name)) {
//			throw new Exception('Invalid name: ' . $name);
//		}
		$new = explode(DIRECTORY_SEPARATOR, $dir);
		array_pop($new);
		array_push($new, $name);
		$new = implode(DIRECTORY_SEPARATOR, $new);
		if($dir !== $new) {
			if(is_file($new) || is_dir($new)) { throw new Exception('Path already exists: ' . $new); }
			rename($dir, $new);
		}
		return array('id' => $this->id($new));
	}
	public function remove($id) {
		$dir = $this->path($id);
		if($dir === $this->base) {
			throw new Exception('Cannot remove root');
		}
		if(is_dir($dir)) {
			foreach(array_diff(scandir($dir), array(".", "..")) as $f) {
				$this->remove($this->id($dir . DIRECTORY_SEPARATOR . $f));
			}
			rmdir($dir);
		}
		if(is_file($dir)) {
			unlink($dir);
		}
		return array('status' => 'OK');
	}
	public function move($id, $par) {
		$dir = $this->path($id);
		$par = $this->path($par);
		$new = explode(DIRECTORY_SEPARATOR, $dir);
		$new = array_pop($new);
		$new = $par . DIRECTORY_SEPARATOR . $new;
		rename($dir, $new);
		return array('id' => $this->id($new));
	}
	public function copy($id, $par) {
		$dir = $this->path($id);
		$par = $this->path($par);
		$new = explode(DIRECTORY_SEPARATOR, $dir);
		$new = array_pop($new);
		$new = $par . DIRECTORY_SEPARATOR . $new;
		if(is_file($new) || is_dir($new)) { throw new Exception('Path already exists: ' . $new); }

		if(is_dir($dir)) {
			mkdir($new);
			foreach(array_diff(scandir($dir), array(".", "..")) as $f) {
				$this->copy($this->id($dir . DIRECTORY_SEPARATOR . $f), $this->id($new));
			}
		}
		if(is_file($dir)) {
			copy($dir, $new);
		}
		return array('id' => $this->id($new));
	}
}


if(isset($_GET['operation'])) {
	
	
	$fs = new fs($FolderTreeLocation);
	
	try {
		$rslt = null;
		switch($_GET['operation']) {
			case 'get_node':
				$node = isset($_GET['id']) && $_GET['id'] !== '#' ? $_GET['id'] : '/';
				$rslt = $fs->lst($node, (isset($_GET['id']) && $_GET['id'] === '#'));
				break;
			case "get_content":
				$node = isset($_GET['id']) && $_GET['id'] !== '#' ? $_GET['id'] : '/';
				$rslt = $fs->data($node);
				break;
			case 'create_node':
				$node = isset($_GET['id']) && $_GET['id'] !== '#' ? $_GET['id'] : '/';
				$rslt = $fs->create($node, isset($_GET['text']) ? $_GET['text'] : '', (!isset($_GET['type']) || $_GET['type'] !== 'file'));
				break;
			case 'rename_node':
				$node = isset($_GET['id']) && $_GET['id'] !== '#' ? $_GET['id'] : '/';
				$rslt = $fs->rename($node, isset($_GET['text']) ? $_GET['text'] : '');
				break;
			case 'delete_node':
				$node = isset($_GET['id']) && $_GET['id'] !== '#' ? $_GET['id'] : '/';
				$rslt = $fs->remove($node);
				break;
			case 'move_node':
				$node = isset($_GET['id']) && $_GET['id'] !== '#' ? $_GET['id'] : '/';
				$parn = isset($_GET['parent']) && $_GET['parent'] !== '#' ? $_GET['parent'] : '/';
				$rslt = $fs->move($node, $parn);
				break;
			case 'copy_node':
				$node = isset($_GET['id']) && $_GET['id'] !== '#' ? $_GET['id'] : '/';
				$parn = isset($_GET['parent']) && $_GET['parent'] !== '#' ? $_GET['parent'] : '/';
				$rslt = $fs->copy($node, $parn);
				break;
			default:
				throw new Exception('Unsupported operation: ' . $_GET['operation']);
				break;
		}
		header('Content-Type: application/json; charset=utf-8');
		echo json_encode($rslt);
	}
	catch (Exception $e) {
		header($_SERVER["SERVER_PROTOCOL"] . ' 500 Server Error');
		header('Status:  500 Server Error');
		echo $e->getMessage();
	}
	die();
	
	
//	}
}
?>
<!DOCTYPE html>
<html>
	<head>
		<meta charset="utf-8">
		<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
		<title>CADViewer JS - Folder Tree</title>
		<meta name="viewport" content="width=device-width" />
		<link rel="stylesheet" href="../app/js/jstree/default/style.min.css" />
		<style>
		html, body { background:#fff; font-size:10px; font-family:Verdana; margin:0; padding:0; }
		#container { min-width:320px; margin:0px auto 0 auto; background:white; border-radius:0px; padding:0px; overflow:hidden; }
		#tree { float:left; min-width:319px; border-right:1px solid silver; overflow:auto; padding:0px 0; }
		#data { margin-left:320px; }
		#data textarea { margin:0; padding:0; height:100%; width:100%; border:0; background:white; display:block; line-height:18px; resize:none; }
		#data, #code { font: normal normal normal 12px/18px 'Consolas', monospace !important; }

		#tree .folder { background:url('./file_sprite.png') right bottom no-repeat; }
		#tree .file { background:url('./file_sprite.png') 0 0 no-repeat; }
		#tree .file-pdf { background-position: -32px 0 }
		#tree .file-as { background-position: -36px 0 }
		#tree .file-c { background-position: -72px -0px }
		#tree .file-iso { background-position: -108px -0px }
		#tree .file-htm, #tree .file-html, #tree .file-xml, #tree .file-xsl { background-position: -126px -0px }
		#tree .file-cf { background-position: -162px -0px }
		#tree .file-cpp { background-position: -216px -0px }
		#tree .file-cs { background-position: -236px -0px }
		#tree .file-sql { background-position: -272px -0px }
		#tree .file-xls, #tree .file-xlsx { background-position: -362px -0px }
		#tree .file-h { background-position: -488px -0px }
		#tree .file-crt, #tree .file-pem, #tree .file-cer { background-position: -452px -18px }
		#tree .file-php { background-position: -108px -18px }
		#tree .file-jpg, #tree .file-jpeg, #tree .file-png, #tree .file-gif, #tree .file-bmp { background-position: -126px -18px }
		#tree .file-ppt, #tree .file-pptx { background-position: -144px -18px }
		#tree .file-rb { background-position: -180px -18px }
		#tree .file-text, #tree .file-txt, #tree .file-md, #tree .file-log, #tree .file-htaccess { background-position: -254px -18px }
		#tree .file-doc, #tree .file-docx { background-position: -362px -18px }
		#tree .file-zip, #tree .file-gz, #tree .file-tar, #tree .file-rar { background-position: -416px -18px }
		#tree .file-js { background-position: -434px -18px }
		#tree .file-css { background-position: -144px -0px }
		#tree .file-fla { background-position: -398px -0px }
		#tree .file-dwg , #tree .file-dxf, #tree .file-dwf, #tree .file-dgn, #tree .file-pcf { background-position: -380px -18px }
		#tree .file-svg { background-position: -54px -18px }
		</style>



	<body>


	<script src="../app/js/jquery-2.2.3.js" type="text/javascript"></script>
	<script src="../app/js/jquery.qtip.min.js" type="text/javascript"></script>
	<link href="../app/css/jquery.qtip.min.css" media="screen" rel="stylesheet" type="text/css" />

	<script src="../app/js/popper.js" type="text/javascript"></script>

	<script src="../app/js/bootstrap.min.js" type="text/javascript"></script>
	<link href="../app/css/bootstrap.min.css" media="screen" rel="stylesheet" type="text/css" />

	<script src="../app/js/jquery-ui-1.11.4.min.js" type="text/javascript"></script>
	<link href="../app/css/jquery-ui-1.11.4.min.css" media="screen" rel="stylesheet" type="text/css" />


	<script src="../app/js/cadviewerjs.min.js" type="text/javascript" ></script>

	<link href="../app/css/cvjs_4.1.0.css" media="screen" rel="stylesheet" type="text/css" />
	<link href="../app/css/layerlist_05.css" media="screen" rel="stylesheet" type="text/css" />

	<script src="../app/js/library_js_svg_path.js" type="text/javascript"></script>			
	<script src="../app/js/snap.svg-min.js" type="text/javascript" ></script>

	<script src="../app/js/axuploader_2_19.js" type="text/javascript" ></script>
	<script src="../app/js/cvjs_api_styles_2_0_26.js" type="text/javascript" ></script>
	<script type="text/javascript" src="../app/js/rgbcolor.js"></script>
	<script type="text/javascript" src="../app/js/StackBlur.js"></script>
	<script type="text/javascript" src="../app/js/canvg.js"></script>
	<script src="../app/js/list.js" type="text/javascript"></script>
	<script src="../app/js/jscolor.js"></script>
	<link href="../app/css/loading_animation_2.css" rel="stylesheet">
	
	<script src="../app/js/jstree/jstree.min.js"></script>
	<script src="../app/js/xml2json.min.js"></script>
		
	<script src="./CV-JS_ServerSettings.js" type="text/javascript"></script>	
<!--	<script src="./CV-JS_ServletHandlerSettings.js" type="text/javascript"></script> -->
	<script src="./CV-JS_AshxhandlerSettings.js" type="text/javascript"></script>
	
	
    <script type="text/javascript">


	
	// Location of installation folders
	// NOTE: THE LOCATION OF THE ServerLocation/ServerUrl VARIABLES ARE DEFINED IN /cadviewer/html/CV-JS_ServerSettings.js
	// PLEASE MOVE OR RENAME APPROPRIATELY
	
	//	var ServerLocation = 
	//	var ServerUrl = 
	
//	var dataLocation = "/html_dev/data/";
//	var dataLocation = "/html/data/";
	
	var generateShareFileDrawingList = false;
	var toggleMenu = false;
	var loadFileFromParam = false;
	
	// FileLocation must be declared, it will be overwritten with the folder_location parameter as part of CVJS_foldertree_312.php?file_location=
	var FileLocation = "../content";
	// Current location must be declared and passed over to file tree generator
	var myLocation = ServerLocation + "html";

	
	
	$(document).ready(function()
		{
			
	
		// Pass over the location of the installation
		cvjs_setServerLocationURL(ServerLocation, ServerUrl);
	
		// For "Merge DWG" / "Merge PDF" commands, set up the email server to send merged DWG files or merged PDF files with redlines/interactive highlight.
		// See php / xampp documentation on how to prepare your server
		cvjs_emailSettings_PDF_publish("From CAD Server", "my_from_address@mydomain.com", "my_cc_address@mydomain.com", "my_reply_to@mydomain.com");


		// CHANGE LANGUAGE - DEFAULT IS ENGLISH
		// window.alert("Avaliable Languages: "+cvjs_getLanguages());
		cvjs_setLanguage("English");
		// Available languages:  "English" ; "French, "Korean", "Spanish", "Portuguese", "Portuguese (Brazil)" ;  "Russian" ; "Malay" ;  "Chinese-Simplified"
		
		

		$("#CADViewerTable").css({position: 'absolute'});

//		$("#CADViewerTable").css("left", 320).css("top", 45);
		$("#CADViewerTable").css("background", "white");
		$("#container").css("background", "white");
		
		var containerWidth = $(this).width();		
		var CVwidth = containerWidth - 320;
		var containerHeight = $(this).height();		
		var CVheight = containerHeight - 45;

		$("#CADViewerTable").css("width", CVwidth);
		$("#CADViewerTable").css("height", CVheight);
			
		$("#menu-toggle").css({position: 'absolute'});
		var containerWidth = $(this).width();		
		var ToggleWidth = containerWidth - 220;
		var ToggleWidth = 580;
		$("#menu-toggle").css("left", ToggleWidth).css("top", 5);
			

		var SaveWidth = containerWidth - 620;
		$("#menu-save-as-pdf").css({position: 'absolute'});
		$("#menu-save-as-pdf").css("left", SaveWidth).css("top", 5);
			

		var ReloadWidth = containerWidth - 339;
		var ReloadWidth = 780;
		$("#menu-reload-page").css({position: 'absolute'});
		$("#menu-reload-page").css("left", ReloadWidth ).css("top", 5);
			
		// overwrite floatNavigation Menu
		var myFloatMenu = "#floatNavigationMenu_"+"floorPlan"+"_svg"		
		$(myFloatMenu).css("left", -260).css("top", -38);
	

		if (toggleMenu){
			// overwrite floatNavigation Menu
			var myFloatMenu = "#floatNavigationMenu_"+"floorPlan"+"_svg"		
			$(myFloatMenu).css("left", 60).css("top", -38);
		}
		else{
			// overwrite floatNavigation Menu
			var myFloatMenu = "#floatNavigationMenu_"+"floorPlan"+"_svg"		
			$(myFloatMenu).css("left", -260).css("top", -38);
		}


		// set the location to license key, typically the js folder in main app application folder ../app/js/
//		cvjs_setLicenseKeyPath("../app/js/");
		

		// set the location to license key, typically the js folder in main app application folder ../app/js/
		 cvjs_setLicenseKeyPath(ServerUrl+"/app/js/");
		// alternatively, set the key directly, by pasting in the cvKey portion of the cvlicense.js file, note the JSON \" around all entities 	 
		// cvjs_setLicenseKeyDirect(' { \"cvKey\": \"00110010 00110010 00110000 00110100 00110010 00110000 00110111 00110001 00110100 00111000 00110001 00110100 00110101 00110001 00110101 00110111 00110001 00110101 00111001 00110001 00110100 00111000 00110001 00110101 00110010 00110001 00110100 00110101 00110001 00110100 00110001 00110001 00110100 00110000 00110001 00111001 00111000 00110010 00110000 00110110 00110010 00110000 00111000 00110010 00110000 00110111 00110001 00111001 00111001 00110010 00110001 00110001 00110010 00110000 00111000 00110010 00110000 00110000 00110010 00110001 00110001 00110010 00110000 00111000 00110010 00110000 00110111 \"  }');



		// Set Icon Menu Interface controls. Users can: 
		// 1: Disable all icon interfaces
		//  cvjs_displayAllInterfaceControls(false, "floorPlan");  // disable all icons for user control of interface
		// 2: Disable either top menu icon menus or navigation menu, or both
		//	cvjs_displayTopMenuIconBar(false, "floorPlan");  // disable top menu icon bar
		//	cvjs_displayTopNavigationBar(false, "floorPlan");  // disable top navigation bar
		// 3: Users can change the number of top menu icon pages and the content of pages, based on a configuration file in folder /cadviewer/app/js/menu_config/
		//  cvjs_setCustomTopMenuXML("cadviewerjs_menu_all_items.xml", "floorPlan");
		//	cvjs_setCustomTopMenuXML("cadviewerjs_menu_viewing_only.xml", "floorPlan");
		//    cvjs_setCustomTopMenuXML("cadviewerjs_menu_all_items_startpage2.xml", "floorPlan");
		//  cvjs_setCustomTopMenuXML("cadviewerjs_menu_all_items_startpage3.xml", "floorPlan");

		// cvjs_InitCADViewerJS_app("floorPlan", "../app/");
		cvjs_InitCADViewerJS_app("floorPlan", ServerUrl+"app/");
		
			
		
		// First, Get the file location from URL
		FileLocation = cvjs_GetURLParameter('file_location');		
		// Then build the right side folder tree and use the returned file-location
		FileLocation = cvjs_buildFolderTree(FileLocation, myLocation, "floorPlan");

		
		cvjs_debugMode(true);
		cvjs_allowFileLoadToServer();

//		cvjs_setUrl_singleDoubleClick(1);
//		cvjs_encapsulateUrl_callback(true);
		

		// NOTE BELOW: THESE SETTINGS ARE FOR SERVER CONTROLS FOR HANDLING OF PRINT OBJECTS and FILE OBJECTS
		// The default settings is using PHP in /php/ folder with controlling documents in /php/ folder and print objects in /php/temp_print
		// Using PHP or Servlets


		// DEFAULT SETTINGS FOR PHP
//      cvjs_setPhpPath("../php/");        // location of php handlers for file upload and modals, typically same path as cvjs_setServerHandlersPath(),
                                           // but can be separated in case of custom implementation of print handlers either as php or servlets
                                           // use an absolute path if using cvjs_setRedlinesAbsolutePath() and cvjs_setInsertImageObjectsAbsolutePath()

//		cvjs_setServerHandlersPath("../php/");          // location of print handlers, in the standard case this in the /php/ folder with redline and file controllers
//		cvjs_setPrintObjectPath("./temp_print/");      // location of print object relative to controller document
//		cvjs_setServerSaveFileHandler("save-file.php");	// name of server side save-file controller document
//		cvjs_setServerAppendFileHandler("append-file.php"); // name of server side append-file controller document
//		cvjs_setServerDeleteFileHandler("delete-file.php"); // name of server side delete-file controller docoment

		// Servlet settings for multipage SVG and multipage PDF conversion
//		cvjs_setServerListDirectoryHandler("list-directory.php");    // server side document to list directories
//		cvjs_setReturnPDFparamsController("return-pdf-convert-params.php");  // server side document to list pdf conversion folder specifics
//		cvjs_setServerPDFConverterController("convert-pdf-files.php");   // server side document to convert pdf multipage documents


		// SAMPLE SETTINGS FOR PHP - WHEN CLEANING UP PRINT OBJECTS AFTER PRINT
		cvjs_setServerHandlersPath(ServerUrl+"php/");    // location of print handlers, in the standard case this in the /php/ folder with redline and file controllers
		cvjs_removePrintObjectAfterPrint(true);
		cvjs_setJavaScriptsJQ_AbsoluteFolder(ServerUrl+"js/jquery-2.2.3.js");



		// SAMPLE SETTINGS FOR SERVLETS - ALTERNATIVE TO DEFAULT PHP SETTING
//		cvjs_setServerHandlersPath("http://localhost:8080/cadviewer/servlets/servlet");          // location of print handlers, in the standard case this in the /php/ folder with redline and file controllers
//		cvjs_setPrintObjectPathAbsolute("http://localhost:8080/cadviewer/temp_print/","C:\\xampp\\tomcat\\webapps\\cadviewer\\temp_print\\");      // absolute location of Print object, url and server
//		cvjs_setServerSaveFileHandlerPrint("SaveServlet");	// name of server side save-file controller document
//		cvjs_setServerAppendFileHandlerPrint("AppendServlet"); // name of server side append-file controller document
//		cvjs_setServerDeleteFileHandlerPrint("DeleteServlet"); // name of server side delete-file controller docoment
//		cvjs_setServerListDirectoryHandler("ListDirectoryContent");
//		cvjs_setServerLoadHandler("LoadServlet");

		// Servlet settings for multipage SVG and multipage PDF conversion
//		cvjs_setServerListDirectoryHandler("ListDirectoryContent");
//		cvjs_setReturnPDFparamsController("ReturnPDFParamsServlet");
//		cvjs_setServerPDFConverterController("ConvertPDFServlet");


		// Custom control of PrintToPDF
		//cvjs_setCustomPDFprintControllerFlag(true);
		//cvjs_setCustomPDFprintController("CustomPrintToPDFServlet");



		// NOTE ABOVE: THESE SETTINGS ARE FOR REPLACING PHP SERVER CONTROLS WITH SERVLETS (OR CUSTOM HANDLERS)


		// NOTE BELOW: THESE SETTINGS ARE FOR SERVER CONTROLS FOR UPLOAD OF REDLINES
		// I am setting the location of the php scripts controlling redlines and file manager relative to (this calling), the default is "../php/"
		// as defined in cvjs_setServerHandlersPath("../php/")


		// REDLINE UPLOAD/SAVE - ALTERNATIVE TO PHP SETTINGS
//		cvjs_setServerSaveHandlerRedlines("SaveRedlinesServlet");	// name of server side save-file controller document
//		cvjs_setServerLoadHandlerRedlines("LoadRedlinesServlet"); // name of server side append-file controller document
//		cvjs_setServerRedlinesListDirectoryHandler("ListDirectoryContent");


		// If the redline load/save is application controlled, the user will set the load/save files using the following methods:
		//cvjs_setStickyNoteRedlineUrl("../redlines/filename-red_t1.js");
		//cvjs_setStickyNoteSaveRedlineUrl("../redlines/filename-red_s1.js");

		// Redines folder location is
		// Redlines folder location used when file-manager is used for upload and redline selection
		//cvjs_setRedlinesRelativePath('../redlines/demo_red/', ServerLocation+'/redlines/demo_red/');
		cvjs_setRedlinesAbsolutePath(ServerUrl+'redlines/demo_red/', ServerLocation+'/redlines/demo_red/');


		// NOTE ABOVE: THESE SETTINGS ARE FOR SERVER CONTROLS FOR UPLOAD OF REDLINES





		// NOTE BELOW: THESE SETTINGS ARE FOR SERVER CONTROLS FOR UPLOAD OF FILES AND FILE MANAGER

		// I am setting the full path to the location of the floorplan drawings (typically  /home/myserver/drawings/floorplans/)
		// and the relative location of floorplans drawings relative to my current location
		// as well as the URL to the location of floorplan drawings with username and password if it is protected "" "" if not


		// cvjs_setServerFileLocation(ServerLocation+'/drawings/demo/floorplans/', '../drawings/demo/floorplans/', ServerUrl+'drawings/demo/floorplans/',"","");
		cvjs_setServerFileLocation_AbsolutePaths(ServerLocation+'/drawings/demo/floorplans/', ServerUrl+'drawings/demo/floorplans/',"","");
		
					

		// NOTE ABOVE: THESE SETTINGS ARE FOR SERVER CONTROLS FOR UPLOAD OF FILES AND FILE MANAGER

		// NOTE BELOW: THESE SETTINGS ARE FOR SERVER CONTROLS FOR CONVERTING DWG, DXF, DWF files

		// PHP - Apache
//		cvjs_setRestApiControllerLocation(ServerUrl+"php/");
//		cvjs_setRestApiController("call-Api_Conversion.php");  	 // AX2020  - controller document for AX2019 server side conversion


		// Tomcat
//			cvjs_setRestApiControllerLocation(ServerUrl+"/servlets/servlet/");
//			cvjs_setRestApiController("callApiConversionServlet");  	 // AX2020  - controller document for AX2020 server side conversion
//			cvjs_setServerAccessToServlet(true);  // We are telling to use Servlets POST instead of php json connection
//			cvjs_restApiConverter("AutoXchange AX2020");
//			cvjs_restApiConverter("V1.00");

        //	ASP.NET
            cvjs_setRestApiControllerLocation(ServerUrl);
            cvjs_setRestApiController("callApiConversionHandler.ashx");  	 // AX2020  - controller document for AX2020 server side conversion
            cvjs_setServerAccessToServlet(true);  // We are telling to use Servlets POST instead of php json connection
            cvjs_restApiConverter("AutoXchange AX2020");
            cvjs_restApiConverter("V1.00");
 

		cvjs_conversion_addAXconversionParameter("POSTFIX", "");



		// If I want to overwrite these values with settings for my own server where I have installed AutoXchange and the controlling scripts,
		//  I can control whem with the methods:
		//      cvjs_Init_ConversionServer(rest_api_url, rest_api_php, username, password);
		// or:  cvjs_setConverterCredentials(username, password);
		// or:  cvjs_setConverter(converter, version);

		// Now I want to set up the parameters for the conversion call, if I do not do anything, the conversion is set up to load FileNameUrl as a file (see RestAPI for other methods),
		// the resulting is located on the server as a stream. This means that CADViewer JS will read up the file and it is deleted on server after reading.
		// The conversion parameters are standard set-up from within AutoXchange:  -prec=2, -size=2800 -ml=0.4
		// When browsing through multiple layouts in a file, for each layout a new conversion will be triggered.


		// Now as an alternative, I want to set the content response to file instead of stream. This means that the server will keep a copy of the file (randomly named)
		// The pros is that I can quicker browse throught the multipages in the file
		// The cons is that loading of first page takes longer and that I need to clean up the server when I leave the page (or at the end of the day)
		// For this to work, I need to set the conversion parameter -basic, so that all pages in the set are converted initially

		// cvjs_conversion_setContentResponse("file");
		// cvjs_conversion_addAXconversionParameter("basic", "");

		// If the file that has to be converted is behind a password protection, set the username/password for picking up the DWG/DWF/DXF file
		// cvjs_setOriginatingFileUsernamePassword(username, password);


		// If I want to control the parameters controls in conversions I will call some of the following methods prior to conversion , see API documentation

		// I want to clear all pre-set autoxchange conversion parameters
		 cvjs_conversion_clearAXconversionParameters();
		// now I want to increase the size of the output drawing, this is useful for large drawings with much detail
		// cvjs_conversion_addAXconversionParameter("size", "4800");
		// now I want to make the minimum lines manually thinner, this is useful for large drawings with much detail, default is 0.6 but an automated process
		// autocorrect the thickness, using this parameter will overwrite this setting
		// cvjs_conversion_addAXconversionParameter("ml", "0.4");
		// I also make a slightly lower precision to make the resulting file smaller, the original drawing has a default of resolution space 2
		// cvjs_conversion_addAXconversionParameter("prec", "1");


		// For the server, I want to tell which path to the xrefs I want to use in this conversion, this is preset on the server to ./files/xref
		// cvjs_conversion_addAXconversionParameter("xpath", "/myserverlocation/files/xrefs2");

		// NOTE ABOVE: THESE SETTINGS ARE FOR SERVER CONTROLS FOR CONVERTING DWG, DXF, DWF files



		// Initialize CADViewer JS  - needs the div name on the svg element on page that contains CADViewerJS and the location of the
		// main application "app" folder. It can be either absolute or relative
	
	    cvjs_resizeWindow_position("floorPlan" );
		
		// Load file - needs the svg div name and name and path of file to load
//		cvjs_LoadDrawing("floorPlan", FileName );


		myparam = cvjs_GetURLParameter('file_name');

		if (myparam!=""){
						
			myparam = myparam.replace(/%20/g, ' ');
			loadFileFromParam = true;
			cvjs_currentFileFromJSTreeFolder = myparam;
			
			//window.alert(cvjs_currentFileFromJSTreeFolder+"   "+loadFileFromParam);
			
		}
		
		// SHAREPOINT FILE HANDLER


		
	
			$('#tree')
				.jstree({
					'core' : {
						'data' : {
							'url' : '?operation=get_node',
							'data' : function (node) {
								return { 'id' : node.id };
							}
						},
						'check_callback' : function(o, n, p, i, m) {
							if(m && m.dnd && m.pos !== 'i') { return false; }
							if(o === "move_node" || o === "copy_node") {
								if(this.get_node(n).parent === this.get_node(p).id) { return false; }
							}
							return true;
						},
						'force_text' : true,
						'themes' : {
							'responsive' : false,
							'variant' : 'small',
							'stripes' : true
						}
					},
					'sort' : function(a, b) {
						return this.get_type(a) === this.get_type(b) ? (this.get_text(a) > this.get_text(b) ? 1 : -1) : (this.get_type(a) >= this.get_type(b) ? 1 : -1);
					},
					'contextmenu' : {
						'items' : function(node) {
							var tmp = $.jstree.defaults.contextmenu.items();
							delete tmp.create.action;
							tmp.create.label = "New";
							tmp.create.submenu = {
								"create_folder" : {
									"separator_after"	: true,
									"label"				: "Folder",
									"action"			: function (data) {
										var inst = $.jstree.reference(data.reference),
											obj = inst.get_node(data.reference);
										inst.create_node(obj, { type : "default" }, "last", function (new_node) {
											setTimeout(function () { inst.edit(new_node); },0);
										});
									}
								},
								"create_file" : {
									"label"				: "File",
									"action"			: function (data) {
										var inst = $.jstree.reference(data.reference),
											obj = inst.get_node(data.reference);
										inst.create_node(obj, { type : "file" }, "last", function (new_node) {
											setTimeout(function () { inst.edit(new_node); },0);
										});
									}
								}
							};
							if(this.get_type(node) === "file") {
								delete tmp.create;
							}
							return tmp;
						}
					},
					'types' : {
						'default' : { 'icon' : 'folder' },
						'file' : { 'valid_children' : [], 'icon' : 'file' }
					},
					'unique' : {
						'duplicate' : function (name, counter) {
							return name + ' ' + counter;
						}
					},
					'plugins' : ['state','dnd','sort','types','contextmenu','unique']
				})
				.on('delete_node.jstree', function (e, data) {
					$.get('?operation=delete_node', { 'id' : data.node.id })
						.fail(function () {
							data.instance.refresh();
						});
				})
				.on('create_node.jstree', function (e, data) {
					$.get('?operation=create_node', { 'type' : data.node.type, 'id' : data.node.parent, 'text' : data.node.text })
						.done(function (d) {
							data.instance.set_id(data.node, d.id);
						})
						.fail(function () {
							data.instance.refresh();
						});
				})
				.on('rename_node.jstree', function (e, data) {
					$.get('?operation=rename_node', { 'id' : data.node.id, 'text' : data.text })
						.done(function (d) {
							data.instance.set_id(data.node, d.id);
						})
						.fail(function () {
							data.instance.refresh();
						});
				})
				.on('move_node.jstree', function (e, data) {
					$.get('?operation=move_node', { 'id' : data.node.id, 'parent' : data.parent })
						.done(function (d) {
							//data.instance.load_node(data.parent);
							data.instance.refresh();
						})
						.fail(function () {
							data.instance.refresh();
						});
				})
				.on('copy_node.jstree', function (e, data) {
					$.get('?operation=copy_node', { 'id' : data.original.id, 'parent' : data.parent })
						.done(function (d) {
							//data.instance.load_node(data.parent);
							data.instance.refresh();
						})
						.fail(function () {
							data.instance.refresh();
						});
				})
				.on('changed.jstree', function (e, data) {
					if(data && data.selected && data.selected.length) {
						$.get('?operation=get_content&id=' + data.selected.join(':'), function (d) {
							if(d && typeof d.type !== 'undefined') {
								$('#data .content').hide();
								switch(d.type) {
									case 'PDF':   
									case 'pdf':   if (!loadFileFromParam) {
										
														var pdfFolderName = d.content.substring(d.content.lastIndexOf("/")+1);
														pdfFolderName = pdfFolderName.substring(0,pdfFolderName.lastIndexOf("."));
														cvjs_setCustomPdfFolder(pdfFolderName, true);											
														cvjs_LoadDrawing("floorPlan", FileLocation + d.content); cvjs_currentFileFromJSTreeFolder = d.content;
																													
													} break;
									case 'DGN':
									case 'PCF':
									case 'DXF':
									case 'DWG':
									case 'DWF':   
									case 'dgn':
									case 'pcf':
									case 'dxf':
									case 'dwg':
									case 'dwf':   if (!loadFileFromParam) {
	
													cvjs_CleanLayout("floorPlan");
													cvjs_LoadDrawing("floorPlan", FileLocation+d.content); cvjs_currentFileFromJSTreeFolder = d.content;
													
													
												} break;
									case 'text':
									case 'txt':
									case 'md':
									case 'htaccess':
									case 'log':
									case 'sql':
									case 'php':
									case 'js':
									case 'json':
									case 'css':
									case 'html': break;
									case 'PNG':
									case 'GIF':
									case 'JPG':
									case 'SVG':
									case 'png':
									case 'jpg':
									case 'jpeg':
									case 'bmp':
									case 'gif':  if (!loadFileFromParam) {cvjs_LoadDrawing("floorPlan", FileLocation + d.content); cvjs_currentFileFromJSTreeFolder = d.content;} break;
									case 'svg':  if (!loadFileFromParam) {cvjs_LoadDrawing("floorPlan", FileLocation + d.content); cvjs_currentFileFromJSTreeFolder = d.content;} break;
									default:
										$('#data .default').html(d.content).show();
										break;
								}
							}
						});
					}
					else {
						$('#data .content').hide();
						$('#data .default').html('Select a file from the tree.').show();
					}
				});
	

	
	   $("#menu-toggle").click(function(e) {
			
			//e.preventDefault();
			//$("#wrapper").toggleClass("toggled");
			ToggleMenu();
		});
					

	   $("#menu-save-as-pdf").click(function(e) {
			//e.preventDefault();
			//$("#wrapper").toggleClass("toggled");			
			saveDrawingWithAnnotationsAsPDF(cvjs_currentFileFromJSTreeFolder, cvjs_sharepoint_UserName, true);
		});
					
					
	   $("#menu-reload-page").click(function(e) {
			//e.preventDefault();
			//$("#wrapper").toggleClass("toggled");			
			//window.alert("reload");
			location.reload();
			
		});
		

//window.alert("loadFileFromParam"+loadFileFromParam);		
	
		var treeWidth = $("#tree").width();
	
		if (loadFileFromParam) {
			ToggleMenu();			
			cvjs_LoadDrawing("floorPlan", cvjs_currentFileFromJSTreeFolder );
			
			if (toggleMenu){
				// overwrite floatNavigation Menu
				var myFloatMenu = "#floatNavigationMenu_"+"floorPlan"+"_svg"		
				$(myFloatMenu).css("left", 60).css("top", -38);
			}
			else{
				// overwrite floatNavigation Menu
				var myFloatMenu = "#floatNavigationMenu_"+"floorPlan"+"_svg"		
//				$(myFloatMenu).css("left", -260).css("top", -38);
				$(myFloatMenu).css("left", -treeWidth+60).css("top", -38);			
			}
			
			//loadFileFromParam = false;
		}else{
			$("#CADViewerTable").css("left", treeWidth).css("top", 45);
			var containerWidth = $(this).width();		
			var CVwidth = containerWidth - treeWidth;
			$("#CADViewerTable").css("width", CVwidth);
			var myFloatMenu = "#floatNavigationMenu_"+"floorPlan"+"_svg"		
			$(myFloatMenu).css("left", -treeWidth+60).css("top", -38);			
		}

 	
		
		
				
   });  // end ready()




   $(window).resize(function() {
			var treeWidth = $("#tree").width();
	
			var containerWidth = $(this).width();		
			var CVwidth = containerWidth - treeWidth;// 300;
			var containerHeight = $(this).height();		
			var CVheight = containerHeight - 50;

			$("#CADViewerTable").css("left", treeWidth).css("top", 45);
					
			$("#CADViewerTable").css("width", CVwidth);
			$("#CADViewerTable").css("height", CVheight);
			

			var ToggleWidth = containerWidth - 220;
			var ToggleWidth = 580;

			$("#menu-toggle").css("left", ToggleWidth).css("top", 5);
	
			var ReloadWidth = containerWidth - 339;
			var ReloadWidth = 780;
			$("#menu-reload-page").css("left", ReloadWidth ).css("top", 5);
			
			var SaveWidth = containerWidth - 620;
			$("#menu-save-as-pdf").css("left", SaveWidth).css("top", 5);
						
			cvjs_resizeWindow_position("floorPlan" );
    
			if (toggleMenu){
				// overwrite floatNavigation Menu
				var myFloatMenu = "#floatNavigationMenu_"+"floorPlan"+"_svg"		
				$(myFloatMenu).css("left", 60).css("top", -38);
			}
			else{
				// overwrite floatNavigation Menu
				var myFloatMenu = "#floatNavigationMenu_"+"floorPlan"+"_svg"		
				$(myFloatMenu).css("left", -treeWidth+60).css("top", -38);
			}

 
   });


/// NOTE: THESE METHODS BELOW ARE JS SCRIPT CALLBACK METHODS FROM CADVIEWER JS, THEY NEED TO BE IMPLEMENTED BUT CAN BE EMPTY



	function cvjs_OnLoadEnd(){
			// generic callback method, called when the drawing is loaded
			// here you fill in your stuff, call DB, set up arrays, etc..
			// this method MUST be retained as a dummy method! - if not implemeted -

			cvjs_resetZoomPan();

			var user_name = "Bob Smith";
			var user_id = "user_1";

			// set a value for redlines
			cvjs_setCurrentStickyNoteValues_NameUserId(user_name, user_id );
			cvjs_setCurrentRedlineValues_NameUserid(user_name, user_id);

			
			loadFileFromParam = false;   // Set to use jtree tree setting


		
			var treeWidth = $("#tree").width();		
			if (toggleMenu){
				// overwrite floatNavigation Menu
				var myFloatMenu = "#floatNavigationMenu_"+"floorPlan"+"_svg"		
				$(myFloatMenu).css("left", 60).css("top", -38);
				
			}
			else{
				$("#CADViewerTable").css("left", treeWidth).css("top", 45);
				// overwrite floatNavigation Menu
				var myFloatMenu = "#floatNavigationMenu_"+"floorPlan"+"_svg"		
//				$(myFloatMenu).css("left", 60).css("top", -38);
				$(myFloatMenu).css("left", -treeWidth+60).css("top", -38);
			}
			
			
			// we set the insert image orignal path to the same location as the drawing
//			cvjs_setInsertImageObjectsAbsolutePath(cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr].substring(0, cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr].lastIndexOf("/")+1 ) , cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr].substring(0, cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr].lastIndexOf("/")+1 ));
		
			cvjs_setInsertImageObjectsAbsolutePath_FileName(cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr].substring(0, cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr].lastIndexOf("/")+1 ) , 
			                                                cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr].substring(0, cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr].lastIndexOf("/")+1 ), 
															cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr].substring(cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr].lastIndexOf("/")+1, cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr].lastIndexOf(".")) ); 
			
//			cvjs_setInsertImageObjectsAbsolutePath(cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr] , cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr] );
	
			$("#loadedFileName").html("<b>File:"+cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr]+"</b>")

	}






	function cvjs_OnLoadEndRedlines(){
			// generic callback method, called when the redline is loaded
			// here you fill in your stuff, hide specific users and lock specific users
			// this method MUST be retained as a dummy method! - if not implemeted -

			// I am hiding users added to the hide user list
			cvjs_hideAllRedlines_HiddenUsersList();

			// I am freezing users added to the lock user list
			cvjs_lockAllRedlines_LockedUsersList();


	}


	// generic callback method, tells which FM object has been clicked
	function cvjs_change_space(){

	}

	function cvjs_graphicalObjectCreated(graphicalObject){

	// do something with the graphics object created!
//		window.alert(graphicalObject);

	}

	function cvjs_ObjectSelected(rmid){
	 	// placeholder for method in tms_cadviewerjs_modal_1_0_14.js   - must be removed when in creation mode and using creation modal
	}

/// NOTE: THESE METHODS ABOVE ARE JS SCRIPT CALLBACK METHODS FROM CADVIEWER JS, THEY NEED TO BE IMPLEMENTED BUT CAN BE EMPTY


/// NOTE: BELOW REDLINE SAVE LOAD CONTROLLERS

// This method is linked to the save redline icon in the imagemap
function cvjs_saveStickyNotesRedlinesUser(){

	// there are two modes, user handling of redlines
	// alternatively use the build in redline file manager

	// Redlines folder location used when file-manager is used for upload and redline selection
	//cvjs_setRedlinesRelativePath('../redlines/demo_red/', ServerLocation+'/redlines/demo_red/');

	// Note we are passing over the current folder to as both parameters to cvjs_setRedlinesAbsolutePath;
	cvjs_setRedlinesAbsolutePath(cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr].substring(0, cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr].lastIndexOf("/")+1 ) , cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr].substring(0, cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr].lastIndexOf("/")+1 ));
	cvjs_openRedlineSaveModal("floorPlan");	
	//cvjs_saveStickyNotesRedlines();
}


// This method is linked to the load redline icon in the imagemap
function cvjs_loadStickyNotesRedlinesUser(){


	// Redlines folder location used when file-manager is used for upload and redline selection
	//cvjs_setRedlinesRelativePath('../redlines/demo_red/', ServerLocation+'/redlines/demo_red/');

	// Note we are passing over the current folder to as both parameters to cvjs_setRedlinesAbsolutePath;
	cvjs_setRedlinesAbsolutePath(cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr].substring(0, cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr].lastIndexOf("/")+1 ) , cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr].substring(0, cvjs_loaddrawing_FileNamePath[cvjs_active_floorplan_div_nr].lastIndexOf("/")+1 ));
	cvjs_openRedlineLoadModal("floorPlan");
//	cvjs_loadStickyNotesRedlines();
			
}

	

function ToggleMenu(){

	toggleMenu = !toggleMenu;

	if (toggleMenu){
		$("#container").hide();
		$("#CADViewerTable").css("left", 0).css("top", 45);
		//$("#CADViewerTable").css("width", 1500);
		//$("#CADViewerTable").css("height", 800);
		
		var containerWidth = $(this).width();		
		var CVwidth = containerWidth-20;
		var containerHeight = $(this).height();		
		var CVheight = containerHeight - 35;

		$("#CADViewerTable").css("width", CVwidth);
		$("#CADViewerTable").css("height", CVheight);
		
		
		
		// overwrite floatNavigation Menu
		var myFloatMenu = "#floatNavigationMenu_"+"floorPlan"+"_svg"		
		$(myFloatMenu).css("left", 60).css("top", -38);
		
			
	}
	else{
		$("#container").show();

		var treeWidth = $("#tree").width();

		var containerWidth = $(this).width();		
		var CVwidth = containerWidth - treeWidth;
		var containerHeight = $(this).height();		
		var CVheight = containerHeight - 35;


		$("#CADViewerTable").css("left", treeWidth).css("top", 45);
		$("#CADViewerTable").css("width", CVwidth);
		$("#CADViewerTable").css("height", CVheight);



		// overwrite floatNavigation Menu
		var myFloatMenu = "#floatNavigationMenu_"+"floorPlan"+"_svg"		
		$(myFloatMenu).css("left", -treeWidth+60).css("top", -38);

		
		
//		$("#CADViewerTable").css("width", 1200);
//		$("#CADViewerTable").css("height", 800);
	}

}
	
	
			
/// NOTE: ABOVE REDLINE SAVE LOAD CONTROLLERS


 	</script>
	</head>

	
	<table border="0" width="1450">
		<tr>
		<td height="10">
				<canvas id="dummy" width="10" height="10"></canvas>
		</td>
		<td width="50"  style="min-width:50px">
			<a href="http://cadviewerjs.com/index.htm"><img src="http://cadviewerjs.com/logoJS.png" width="46" height="46" alt="Tailor Made logo" /></a>
		</td>
		<td>
		<canvas id="dummy" width="750" height="10"></canvas>
		</td>
		<td>
		<td width="750" style="float:right;margin-top:4px"><div id="loadedFileName" style="float:right;margin-top:7px"><b>File:<b</div>
		<strong></strong>
		</td>

		<td>		
		<a style="float:left"  class="btn btn-default" id="menu-reload-page">Reload Page</a>
		</td>
		<td width="200">
		<a style="float:right"  class="btn btn-default" id="menu-toggle">Collapse/Expand Folders</a>	
		</td>
		</tr>
	</table>


		<div id="container" role="main" style="overflow-y:auto; max-height: 90vh;">
			<div id="tree"></div>
		</div>
	

	<table id="CADViewerTable"  width="1200" height="1000" border="1">
	<tr >

	<td style="vertical-align: top;">

	<div id="floorPlan"></div>


	<!--End of CADViewer JS declaration -->
	</td>
	</tr>
	</table>
		
	

	</body>
</html>